@@ -26,7 +26,6 @@ describe 'ironic::conductor' do
     { :package_ensure                => 'present',
       :enabled                       => true,
       :enabled_hardware_types        => ['ipmi'],
-      :max_time_interval             => '120',
       :force_power_state_during_sync => true }
   end
 
@@ -63,13 +62,12 @@ describe 'ironic::conductor' do
 
     it 'configures ironic.conf' do
       is_expected.to contain_ironic_config('DEFAULT/enabled_hardware_types').with_value('ipmi')
-      is_expected.to contain_ironic_config('conductor/max_time_interval').with_value(p[:max_time_interval])
       is_expected.to contain_ironic_config('conductor/force_power_state_during_sync').with_value(p[:force_power_state_during_sync])
       is_expected.to contain_ironic_config('conductor/automated_clean').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('conductor/api_url').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/cleaning_network').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/provisioning_network').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/rescuing_network').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('neutron/inspection_network').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('deploy/continue_if_disk_secure_erase_fails').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('deploy/http_url').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('deploy/http_root').with(:value => '<SERVICE DEFAULT>')
@@ -91,13 +89,13 @@ describe 'ironic::conductor' do
       before :each do
         params.merge!(
           :enabled_hardware_types            => ['ipmi', 'irmc'],
-          :max_time_interval                 => '50',
           :force_power_state_during_sync     => false,
           :automated_clean                   => false,
           :cleaning_network                  => '00000000-0000-0000-0000-000000000000',
           :api_url                           => 'https://127.0.0.1:6385',
           :provisioning_network              => '00000000-0000-0000-0000-000000000000',
           :rescuing_network                  => '00000000-0000-0000-0000-000000000000',
+          :inspection_network                => '00000000-0000-0000-0000-000000000000',
           :cleaning_disk_erase               => 'metadata',
           :http_url                          => 'http://host:port',
           :http_root                         => '/src/www',
@@ -122,13 +120,13 @@ describe 'ironic::conductor' do
       end
       it 'should replace default parameter with new value' do
         is_expected.to contain_ironic_config('DEFAULT/enabled_hardware_types').with_value('ipmi,irmc')
-        is_expected.to contain_ironic_config('conductor/max_time_interval').with_value(p[:max_time_interval])
         is_expected.to contain_ironic_config('conductor/force_power_state_during_sync').with_value(p[:force_power_state_during_sync])
         is_expected.to contain_ironic_config('conductor/automated_clean').with_value(p[:automated_clean])
         is_expected.to contain_ironic_config('conductor/api_url').with_value(p[:api_url])
         is_expected.to contain_ironic_config('neutron/cleaning_network').with_value('00000000-0000-0000-0000-000000000000')
         is_expected.to contain_ironic_config('neutron/provisioning_network').with_value('00000000-0000-0000-0000-000000000000')
         is_expected.to contain_ironic_config('neutron/rescuing_network').with_value('00000000-0000-0000-0000-000000000000')
+        is_expected.to contain_ironic_config('neutron/inspection_network').with_value('00000000-0000-0000-0000-000000000000')
         is_expected.to contain_ironic_config('deploy/erase_devices_priority').with_value(0)
         is_expected.to contain_ironic_config('deploy/erase_devices_metadata_priority').with_value(10)
         is_expected.to contain_ironic_config('deploy/http_url').with_value(p[:http_url])
@@ -159,12 +157,14 @@ describe 'ironic::conductor' do
           :provisioning_network_name => 'abc',
           :cleaning_network_name => 'abc',
           :rescuing_network_name => 'abc',
+          :inspection_network_name => 'abc',
         )
       end
       it 'should set provisioning/cleaning/rescuing with new value' do
           is_expected.to contain_ironic_config('neutron/cleaning_network').with_value('abc').with_transform_to('net_uuid')
           is_expected.to contain_ironic_config('neutron/provisioning_network').with_value('abc').with_transform_to('net_uuid')
           is_expected.to contain_ironic_config('neutron/rescuing_network').with_value('abc').with_transform_to('net_uuid')
+          is_expected.to contain_ironic_config('neutron/inspection_network').with_value('abc').with_transform_to('net_uuid')
       end
     end
 
